aboutsummaryrefslogtreecommitdiffstats
path: root/src/kern.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/kern.h')
-rw-r--r--src/kern.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/src/kern.h b/src/kern.h
index 5bd191c..3810c5f 100644
--- a/src/kern.h
+++ b/src/kern.h
@@ -55,14 +55,13 @@ char *get_fbpath (int altpath, int fbno);
* Get the dimensions of a framebuffer.
*
* @param fbno The number of the framebuffer.
* @param fbpath The path to the framebuffer device..
* @param width Output parameter for the width of the image.
* @param height Output parameter for the height of the image.
* @parma data Additional data to pass to `convert_fb_to_png`.
* @return Zero on success, -1 on error.
*/
-int measure (int fbno, char *restrict fbpath, long *restrict width,
- long *restrict height, void **restrict data);
+int measure (int fbno, int fbfd, long *restrict width, long *restrict height, void **restrict data);
/**
* Convert read data from a framebuffer to PNG pixel data.
@@ -55,14 +55,13 @@ char *get_fbpath (int altpath, int fbno);
*
* @param fbno The number of the framebuffer.
- * @param fbpath The path to the framebuffer device..
+ * @param fbfd File descriptor for framebuffer device.
* @param width Output parameter for the width of the image.
* @param height Output parameter for the height of the image.